@@ -7,6 +7,7 @@ import warnings
 
 from astropy.convolution import Gaussian2DKernel
 from astropy.stats import gaussian_fwhm_to_sigma, sigma_clipped_stats
+from astropy.utils.decorators import deprecated_renamed_argument
 import numpy as np
 
 from .core import SegmentationImage
@@ -65,10 +66,10 @@ def detect_threshold(data, nsigma, background=None, error=None, mask=None,
         when calculating the image background statistics.
 
     sigclip_iters : int, optional
-       The maximum number of iterations to perform sigma clipping, or
-       `None` to clip until convergence is achieved (i.e., continue
-       until the last iteration clips nothing) when calculating the
-       image background statistics.
+        The maximum number of iterations to perform sigma clipping, or
+        `None` to clip until convergence is achieved (i.e., continue
+        until the last iteration clips nothing) when calculating the
+        image background statistics.
 
     Returns
     -------
@@ -162,8 +163,8 @@ def _make_binary_structure(ndim, connectivity):
     return selem
 
 
-def _detect_sources(data, thresholds, npixels, filter_kernel=None,
-                    connectivity=8, mask=None, deblend_skip=False):
+def _detect_sources(data, thresholds, npixels, kernel=None, connectivity=8,
+                    mask=None, deblend_skip=False):
     """
     Detect sources above a specified threshold value in an image and
     return a `~photutils.segmentation.SegmentationImage` object.
@@ -195,9 +196,9 @@ def _detect_sources(data, thresholds, npixels, filter_kernel=None,
         that an object must have to be detected.  ``npixels`` must be a
         positive integer.
 
-    filter_kernel : array-like (2D) or `~astropy.convolution.Kernel2D`, optional
+    kernel : array-like (2D) or `~astropy.convolution.Kernel2D`, optional
         The 2D array of the kernel used to filter the image before
-        thresholding.  Filtering the image will smooth the noise and
+        thresholding. Filtering the image will smooth the noise and
         maximize detectability of objects with a shape similar to the
         kernel.
 
@@ -240,9 +241,9 @@ def _detect_sources(data, thresholds, npixels, filter_kernel=None,
             raise ValueError('mask must have the same shape as the input '
                              'image.')
 
-    if filter_kernel is not None:
-        data = _filter_data(data, filter_kernel, mode='constant',
-                            fill_value=0.0, check_normalization=True)
+    if kernel is not None:
+        data = _filter_data(data, kernel, mode='constant', fill_value=0.0,
+                            check_normalization=True)
 
     selem = _make_binary_structure(data.ndim, connectivity)
 
@@ -297,8 +298,9 @@ def _detect_sources(data, thresholds, npixels, filter_kernel=None,
     return segms
 
 
-def detect_sources(data, threshold, npixels, filter_kernel=None,
-                   connectivity=8, mask=None):
+@deprecated_renamed_argument('filter_kernel', 'kernel', '1.2')
+def detect_sources(data, threshold, npixels, kernel=None, connectivity=8,
+                   mask=None):
     """
     Detect sources above a specified threshold value in an image and
     return a `~photutils.segmentation.SegmentationImage` object.
@@ -329,9 +331,9 @@ def detect_sources(data, threshold, npixels, filter_kernel=None,
         that an object must have to be detected.  ``npixels`` must be a
         positive integer.
 
-    filter_kernel : array-like (2D) or `~astropy.convolution.Kernel2D`, optional
+    kernel : array-like (2D) or `~astropy.convolution.Kernel2D`, optional
         The 2D array of the kernel used to filter the image before
-        thresholding.  Filtering the image will smooth the noise and
+        thresholding. Filtering the image will smooth the noise and
         maximize detectability of objects with a shape similar to the
         kernel.
 
@@ -357,59 +359,49 @@ def detect_sources(data, threshold, npixels, filter_kernel=None,
 
     See Also
     --------
-    :func:`photutils.segmentation.detect_threshold`,
-    :class:`photutils.segmentation.SegmentationImage`,
+    :func:`photutils.segmentation.detect_threshold`
+    :class:`photutils.segmentation.SegmentationImage`
     :func:`photutils.segmentation.source_properties`
     :func:`photutils.segmentation.deblend_sources`
 
     Examples
     --------
-
     .. plot::
         :include-source:
 
-        # make a table of Gaussian sources
-        from astropy.table import Table
-        table = Table()
-        table['amplitude'] = [50, 70, 150, 210]
-        table['x_mean'] = [160, 25, 150, 90]
-        table['y_mean'] = [70, 40, 25, 60]
-        table['x_stddev'] = [15.2, 5.1, 3., 8.1]
-        table['y_stddev'] = [2.6, 2.5, 3., 4.7]
-        table['theta'] = np.array([145., 20., 0., 60.]) * np.pi / 180.
+        from astropy.convolution import Gaussian2DKernel
+        from astropy.stats import gaussian_fwhm_to_sigma
+        from astropy.visualization import simple_norm
+        import matplotlib.pyplot as plt
+        from photutils.datasets import make_100gaussians_image
+        from photutils.segmentation import detect_threshold, detect_sources
 
-        # make an image of the sources with Gaussian noise
-        from photutils.datasets import make_gaussian_sources_image
-        from photutils.datasets import make_noise_image
-        shape = (100, 200)
-        sources = make_gaussian_sources_image(shape, table)
-        noise = make_noise_image(shape, distribution='gaussian', mean=0.,
-                                 stddev=5., seed=0)
-        image = sources + noise
+        # make a simulated image
+        data = make_100gaussians_image()
 
         # detect the sources
-        from photutils.segmentation import detect_threshold, detect_sources
-        threshold = detect_threshold(image, nsigma=3)
-        from astropy.convolution import Gaussian2DKernel
-        kernel_sigma = 3.0 / (2.0 * np.sqrt(2.0 * np.log(2.0)))  # FWHM = 3
-        kernel = Gaussian2DKernel(kernel_sigma, x_size=3, y_size=3)
+        threshold = detect_threshold(data, nsigma=3)
+        sigma = 3.0 * gaussian_fwhm_to_sigma   # FWHM = 3.
+        kernel = Gaussian2DKernel(sigma, x_size=3, y_size=3)
         kernel.normalize()
-        segm = detect_sources(image, threshold, npixels=5,
-                              filter_kernel=kernel)
+        segm = detect_sources(data, threshold, npixels=5, kernel=kernel)
 
         # plot the image and the segmentation image
-        import matplotlib.pyplot as plt
-        fig, (ax1, ax2) = plt.subplots(2, 1, figsize=(8, 8))
-        ax1.imshow(image, origin='lower', interpolation='nearest')
-        ax2.imshow(segm.data, origin='lower', interpolation='nearest')
+        fig, (ax1, ax2) = plt.subplots(2, 1, figsize=(8, 10))
+        norm = simple_norm(data, 'sqrt', percent=99.)
+        ax1.imshow(data, origin='lower', interpolation='nearest',
+                   norm=norm)
+        ax2.imshow(segm.data, origin='lower', interpolation='nearest',
+                   cmap=segm.make_cmap(seed=1234))
+        plt.tight_layout()
     """
-    return _detect_sources(data, (threshold,), npixels,
-                           filter_kernel=filter_kernel,
+    return _detect_sources(data, (threshold,), npixels, kernel=kernel,
                            connectivity=connectivity, mask=mask)[0]
 
 
+@deprecated_renamed_argument('filter_kernel', 'kernel', '1.2')
 def make_source_mask(data, nsigma, npixels, mask=None, filter_fwhm=None,
-                     filter_size=3, filter_kernel=None, sigclip_sigma=3.0,
+                     filter_size=3, kernel=None, sigclip_sigma=3.0,
                      sigclip_iters=5, dilate_size=11):
     """
     Make a source mask using source segmentation and binary dilation.
@@ -438,18 +430,18 @@ def make_source_mask(data, nsigma, npixels, mask=None, filter_fwhm=None,
     filter_fwhm : float, optional
         The full-width at half-maximum (FWHM) of the Gaussian kernel to
         filter the image before thresholding.  ``filter_fwhm`` and
-        ``filter_size`` are ignored if ``filter_kernel`` is defined.
+        ``filter_size`` are ignored if ``kernel`` is defined.
 
     filter_size : float, optional
         The size of the square Gaussian kernel image.  Used only if
         ``filter_fwhm`` is defined.  ``filter_fwhm`` and ``filter_size``
-        are ignored if ``filter_kernel`` is defined.
+        are ignored if ``kernel`` is defined.
 
-    filter_kernel : array-like (2D) or `~astropy.convolution.Kernel2D`, optional
+    kernel : array-like (2D) or `~astropy.convolution.Kernel2D`, optional
         The 2D array of the kernel used to filter the image before
-        thresholding.  Filtering the image will smooth the noise and
-        maximize detectability of objects with a shape similar to the
-        kernel.  ``filter_kernel`` overrides ``filter_fwhm`` and
+        thresholding. Filtering the image will smooth the noise
+        and maximize detectability of objects with a shape similar
+        to the kernel. ``kernel`` overrides ``filter_fwhm`` and
         ``filter_size``.
 
     sigclip_sigma : float, optional
@@ -457,10 +449,10 @@ def make_source_mask(data, nsigma, npixels, mask=None, filter_fwhm=None,
         when calculating the image background statistics.
 
     sigclip_iters : int, optional
-       The maximum number of iterations to perform sigma clipping, or
-       `None` to clip until convergence is achieved (i.e., continue
-       until the last iteration clips nothing) when calculating the
-       image background statistics.
+        The maximum number of iterations to perform sigma clipping, or
+        `None` to clip until convergence is achieved (i.e., continue
+        until the last iteration clips nothing) when calculating the
+        image background statistics.
 
     dilate_size : int, optional
         The size of the square array used to dilate the segmentation
@@ -477,17 +469,14 @@ def make_source_mask(data, nsigma, npixels, mask=None, filter_fwhm=None,
                                  mask=mask, sigclip_sigma=sigclip_sigma,
                                  sigclip_iters=sigclip_iters)
 
-    kernel = None
-    if filter_kernel is not None:
-        kernel = filter_kernel
-    if filter_fwhm is not None:
+    if kernel is None and filter_fwhm is not None:
         kernel_sigma = filter_fwhm * gaussian_fwhm_to_sigma
         kernel = Gaussian2DKernel(kernel_sigma, x_size=filter_size,
                                   y_size=filter_size)
     if kernel is not None:
         kernel.normalize()
 
-    segm = detect_sources(data, threshold, npixels, filter_kernel=kernel)
+    segm = detect_sources(data, threshold, npixels, kernel=kernel)
     if segm is None:
         return np.zeros(data.shape, dtype=bool)
 
